==> hermes-3.0.1.26.tar.gz: hermes-3.0.1.26/lib/hermes/bo_client/mappings/housing_application_map.rb <==
# frozen_string_literal: true

module Hermes
  module BoClient
    # extending Mapping Module from base_map.rb
    module Mappings
      # handle HousingRequest model mapping for xml data send
      class HousingApplicationMap
        include Hermes::BoClient::Mappings::Concerns::BaseMap
        
        def initialize(options)
          housing_request_id = options[:housing_request_id]
          @date_creation_evenement = options[:date_creation_evenement]
          @rang = options[:rang]
          @date_survenance_evenement = options[:date_survenance_evenement]
          @status_updated_at = options[:status_updated_at]
          @housing_request = Hermes::HousingRequest.find_by(id: housing_request_id)
          @main_object = Hermes::HousingApplication.find_by(id: options[:housing_application_id])
          @code_evenement = options[:code_evenement]
          self.main_object = @main_object
      
          @housing_offer = Hermes::HousingOffer.find_by(id: options[:housing_offer_id])
          @map = {}
        end
        
        def code_evenement
          @code_evenement
        end
        
        def refInterneDemande
          @housing_request&.als_id&.to_s
        end
        
        def refInterneOffre
          @housing_offer&.id.to_s
        end
        
        def date_creation_evenement
          @date_creation_evenement&.to_date
        end

        def rang
          @rang
        end

        def date_survenance_evenement
          @date_survenance_evenement&.to_date
        end

        def status_updated_at
          @status_updated_at&.to_date
        end

     
      end
    end
  end
end

==> hermes-6.0.3.14.tar.gz: hermes-6.0.3.14/lib/hermes/bo_client/mappings/housing_application_map.rb <==
# frozen_string_literal: true

module Hermes
  module BoClient
    # extending Mapping Module from base_map.rb
    module Mappings
      # handle HousingRequest model mapping for xml data send
      class HousingApplicationMap
        include Hermes::BoClient::Mappings::Concerns::BaseMap
        
        def initialize(options)
          housing_request_id = options[:housing_request_id]
          @date_evenement = options[:date_evenement]
          @rang = options[:rang]
          @date_survenance_evenement = options[:date_survenance_evenement]
          @status_updated_at = options[:status_updated_at]
          @housing_request = Hermes::HousingRequest.find_by(id: housing_request_id)
          @main_object = Hermes::HousingApplication.find_by(id: options[:housing_application_id])
          @code_evenement = options[:code_evenement]
          self.main_object = @main_object
      
          @housing_offer = Hermes::HousingOffer.find_by(id: options[:housing_offer_id])
          @map = {}
        end
        
        def code_evenement
          @code_evenement
        end
        
        def refInterneDemande
          @housing_request&.als_id&.to_s
        end
        
        def refInterneOffre
          @housing_offer&.id.to_s
        end
        
        def date_evenement
          @date_evenement&.to_date
        end

        def date_survenance_evenement
          @date_survenance_evenement&.to_date
        end

        def rang_decision
          @rang&.to_s
        end

        def status_updated_at
          @status_updated_at&.to_date
        end
      end
    end
  end
end
